Contributing
============

* New features should be discussed on the mailing list (or in the meetings) before serious work starts
* Pull requests will be rejected if sufficient tests aren't provided
* Please update the documentation when altering behaviour or introducing new features 

Contents:

.. toctree::
   :maxdepth: 2

   contributing/installation
   contributing/testing
   contributing/conventions
